@@ -4,4 +4,4 @@ from .ve_api import AztVeApi, AztVeSpi
 from .structs import api_struct, spi_struct
 from .tools.azt_errors import *
 from .protobufs import EnumType_pb2 as AztEnum
-from .tools.azt_logger import log, warning, error
+from .tools.azt_logger import debug, log, warning, error, init_azt_log
