@@ -1,3 +1,13 @@
+# 服务器连接失败
+class ConnectedFailed(ConnectionError):
+    pass
+
+
+# 服务器连接中断
+class ConnectedBroken(ConnectionError):
+    pass
+
+
 # 尚未登录
 class NotLoginedError(Exception):
     pass
