@@ -55,6 +55,9 @@ class CVexchangeTraderSpi(ABC):
     def onQueryHistoryAccReq(self, msg):
         pass
 
+    def onQueryHistoryDepositReq(self, msg):
+        pass
+
 
 class CVexchangeTraderApi:
     def __init__(self):
@@ -74,6 +77,8 @@ class CVexchangeTraderApi:
         # 设置信号
         self._logined = False
         self.__closed = False
+        # 保存登录信息
+        # self._login_info = None
         # 同步管道
         self._queue_map = dict()
         # # 设置client_ref标识
@@ -170,6 +175,9 @@ class CVexchangeTraderApi:
     def QueryHistoryAccReq(self, req_msg: MsgProto.QryHisAccReq):
         self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_QryHisAccReq))
 
+    def QueryHistoryDepositReq(self, req_msg: MsgProto.QryHisDepositReq):
+        self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_QryHisDepositReq))
+
     # ------ PlaceOrder ------
     def PlaceOrder(self, req_msg: MsgProto.PlaceOrder):
         self.__socket.send(self.__gen_unit_msg(req_msg, EnumProto.KTradeReqType_PlaceOrder))
@@ -186,7 +194,7 @@ class CVexchangeTraderApi:
         except KeyboardInterrupt:
             exit(1)
         except Exception as e:
-            raise e
+            return e
 
     @staticmethod
     def _gen_client_ref():
@@ -242,10 +250,13 @@ class CVexchangeTraderApi:
             time.sleep(self._heart_beat_interval)
             if self._heart_beat_count < self._heart_beat_times:
                 azt_logger.warning(
-                    f"心跳接收异常！正在确认心跳...{self._heart_beat_times - self._heart_beat_count + 1}/{self._heart_beat_times}")
+                    f"心跳接收异常！正在确认心跳...{self._heart_beat_times - self._heart_beat_count + 1}")
         # if not self.__closed:
+
         azt_logger.error("与服务器连接已中断！")
-        self._close()
+        err = self._close()
+        if err:
+            raise err
         # raise azt_errors.ConnectedBroken
 
     def __report_recv(self):  # 加__作为私有方法
@@ -287,6 +298,7 @@ class CVexchangeTraderApi:
             unit_msg.msg_body.Unpack(msg)
             # azt_logger.debug(msg)
             cbmsg = spi_struct.LoginAck.__proto2py__(msg)
+            # self._login_info = cbmsg
             self.spi.onUserLoginReq(cbmsg)
             if "onUserLoginReq" in self._queue_map:
                 self._queue_map["onUserLoginReq"].put(cbmsg, block=False)
@@ -373,6 +385,13 @@ class CVexchangeTraderApi:
             self.spi.onQueryHistoryAccReq(cbmsg)
             if "onQueryHistoryAccReq" in self._queue_map:
                 self._queue_map["onQueryHistoryAccReq"].put(cbmsg, block=False)
+        elif unit_msg.msg_id == EnumProto.KTradeReqType_QryHisDepositAck:
+            msg = MsgProto.QryHisDepositAck()
+            unit_msg.msg_body.Unpack(msg)
+            cbmsg = spi_struct.QryHisDepositAck.__proto2py__(msg)
+            self.spi.onQueryHistoryDepositReq(cbmsg)
+            if "onQueryHistoryDepositReq" in self._queue_map:
+                self._queue_map["onQueryHistoryDepositReq"].put(cbmsg, block=False)
         # ----------------------------------------------------------
         elif unit_msg.msg_id == EnumProto.KTradeRspType_OrdStatusReport:
             msg = MsgProto.OrdReport()
